@@ -192,7 +192,7 @@ class BaseElement:
         self.set_value(val)
 
     @property
-    def parent_tk_widget(self) ->tk.Widget:
+    def parent_tk_widget(self) -> tk.Widget:
         """
         This will be used to store all contained Widgets into
         :return:
@@ -246,7 +246,7 @@ class BaseElement:
 
         kwargs = self.defaults.apply(kwargs)
 
-        self._update_options = kwargs.copy()
+        self._update_options.update(kwargs)
 
         kwargs = dict(filter(lambda a: not self._update_special_key(*a), kwargs.items()))
         self._update_default_keys(kwargs)
@@ -265,8 +265,6 @@ class BaseElement:
         """
         kwargs = remove_None_vals(kwargs)
 
-        self._update_options.update(kwargs)
-
         self._update_initial(**kwargs)
 
         return self
@@ -359,13 +357,10 @@ class BaseWidget(BaseElement):
 
     _transfer_keys: dict[str:str] = dict()   # Rename a key from the update-function. from -> to; from_user -> to_widget
 
-    _events_to_bind_later: list[dict]
-
     _tk_scrollbar_y: tk.Scrollbar | None = None
 
     def __init__(self,key:Any=None,tk_kwargs:dict[str:Any]=None,expand:bool = False,expand_y:bool = False,**kwargs):
         super().__init__()
-        self._events_to_bind_later = list()
 
         if tk_kwargs is None:
             tk_kwargs = dict()
@@ -387,6 +382,17 @@ class BaseWidget(BaseElement):
         if expand_y:
             self.add_flags(ElementFlag.EXPAND_VERTICALLY)
 
+    # Somehow doesn't work with run_after_window_creation-decorator :C
+    # No exceptions, the focus just doesn't get set.
+    # Open to suggestions...
+    def set_focus(self) -> Self:
+        """
+        Set focus on this element
+        :return:
+        """
+        self.tk_widget.focus_set()
+        return self
+
     def _window_is_dead(self) -> bool:
         """
         Returns True, if the window doesn't exist (anymore?)
@@ -396,8 +402,19 @@ class BaseWidget(BaseElement):
 
     @property
     def tk_widget(self) -> tk.Widget:
+        assert hasattr(self, "_tk_widget"), ("The tk_widget doesn't exist (yet?).\n"
+                                             "Do whatever caused the exception AFTER creating the window, that should fix it.")
         return self._tk_widget
 
+    def _bind_event_to_widget(self, tk_event: str, event_function: Callable) -> Self:
+        """Called in 'bind_event'. Inherit this is the event must be bound differently."""
+        self._tk_widget.bind(
+            tk_event,
+            event_function,
+        )
+        return self
+
+    @run_after_window_creation
     def bind_event(self,tk_event:str|Event,key_extention:Union[str,Any]=None,key:Any=None,key_function:Callable|Iterable[Callable]=None)->Self:
         """
         Bind a tk-event onto the underlying tk-widget
@@ -412,15 +429,6 @@ class BaseWidget(BaseElement):
         """
         new_key = None
 
-        if not self.has_flag(ElementFlag.IS_CREATED):
-            self._events_to_bind_later.append({
-                "tk_event":tk_event,
-                "key_extention":key_extention,
-                "key":key,
-                "key_function":key_function,
-            })
-            return self
-
         if hasattr(tk_event,"value"):
             tk_event = tk_event.value
 
@@ -438,12 +446,9 @@ class BaseWidget(BaseElement):
                 new_key = self.key
                 assert new_key or key_function, f"You forgot to add either a key or key_function to this element... {self}"
 
-        temp = self.window.get_event_function(self, new_key, key_function=key_function)
+        event_function = self.window.get_event_function(self, new_key, key_function=key_function)
 
-        self._tk_widget.bind(
-            tk_event,
-            temp
-        )
+        self._bind_event_to_widget(tk_event, event_function)
 
         return self
 
@@ -636,10 +641,6 @@ class BaseWidget(BaseElement):
     def init_window_creation_done(self):
         super().init_window_creation_done()
 
-        for params in self._events_to_bind_later:
-            self.bind_event(**params)
-        del self._events_to_bind_later  # Free some ram, because why not
-
         if self._grab_anywhere_on_this:
             self.window.bind_grab_anywhere_to_element(self.tk_widget)
 
