@@ -2,18 +2,20 @@
 # This is used to make SwiftGUI compatible with python 3.10
 
 import sys
+from collections.abc import Iterator
 
 if sys.version_info >= (3, 11):
     from typing import Self
 else:
-    from typing import TypeVar
+    from typing import TypeVar, Generator
+
     Self = TypeVar("Self", bound= "Any")
 
 if sys.version_info >= (3, 12):
     from itertools import batched
 else:
     # Implement it myself if it's not available...
-    def batched(it, n: int):
+    def batched(it, n: int) -> Iterator[tuple]:
         collected = list()
         it = list(it)
 
@@ -21,13 +23,13 @@ else:
         for elem in it:
             if num == n:
                 num = 0
-                yield collected.copy()
+                yield tuple(collected)
                 collected.clear()
 
             collected.append(elem)
             num += 1
 
         if collected:
-            yield collected
+            yield tuple(collected)
 
 
